#
# spec file for package python-pyOpenSSL
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-pyOpenSSL
Version:        17.5.0
Release:        lp150.7.1
Summary:        Python wrapper module around the OpenSSL library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/pyca/pyopenssl
Source:         https://files.pythonhosted.org/packages/source/p/pyOpenSSL/pyOpenSSL-%{version}.tar.gz
Patch0:         bug-lp-1265482.diff
Patch1:         skip-networked-test.patch
Patch2:         rsa128-i586.patch
Patch3:         X509_STORE_add_cert.patch
# PATCH-FIX-OPENSUSE openSSL_111d.patch bsc#1149792 mcepl@suse.com
# Make tests compatible with OpenSSL 1.1.1c
Patch4:         openSSL_111d.patch
BuildRequires:  %{python_module cryptography >= 2.1.4}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest >= 3.0.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  openssl-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-cryptography >= 2.1.4
Requires:       python-six >= 1.5.2
Provides:       pyOpenSSL = %{version}
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-openssl < %{version}
Provides:       %{oldpython}-openssl = %{version}
%endif
%python_subpackages

%description
pyOpenSSL is a set of Python bindings for OpenSSL.  It includes some low-level
cryptography APIs but is primarily focused on providing an API for using the
TLS protocol from Python.

pyOpenSSL is now a pure-Python project with a dependency on a new project,
cryptography (<https://github.com/pyca/cryptography>), which provides (among
other things) a cffi-based interface to OpenSSL.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML

%description -n %{name}-doc
Provides documentation for %{name}.

%prep
%setup -q -n pyOpenSSL-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
PYTHONPATH="%{buildroot}%{python3_sitelib}" python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%check
export LC_ALL=en_US.UTF-8
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
py.test-%{$python_bin_suffix} -m "not network" -k "not test_export_text"
}

%files %{python_files}
%doc *.rst
%license LICENSE
%{python_sitelib}/OpenSSL/
%{python_sitelib}/pyOpenSSL-%{version}-py*.egg-info

%files -n %{name}-doc
%doc build/sphinx/html/
%doc examples/

%changelog
* Wed Sep 25 2019 Matej Cepl <mcepl@suse.com>
- Add openSSL_111d.patch (bsc#1149792) fixing incompatibility
  with OpenSSL 1.1.1d.
* Fri Oct  5 2018 Vítězslav Čížek <vcizek@suse.com>
- OpenSSL changed X509_STORE_add_cert in 1.1.0i such that it no longer
  raises an error if a duplicate cert is added (bsc#1110435)
  * https://github.com/pyca/pyopenssl/pull/787
  * add X509_STORE_add_cert.patch
* Fri Feb  2 2018 tchvatal@suse.com
- Update to 17.5.0:
  * The minimum cryptography version is now 2.1.4.
  * Fixed various memory leaks
  * Various fuzz fixes
  * See CHANGELOG.rst
* Wed Aug 23 2017 tbechtold@suse.com
- update to 17.2.0:
  - Deprecated ``OpenSSL.rand`` - callers should use ``os.urandom()`` instead.
  - Fixed a bug causing ``Context.set_default_verify_paths()`` to not work with
    cryptography ``manylinux1`` wheels on Python 3.x.
  - Fixed a crash with (EC)DSA signatures in some cases.
  - Removed the deprecated ``OpenSSL.rand.egd()`` function.
    Applications should prefer ``os.urandom()`` for random number generation.
  - Removed the deprecated default ``digest`` argument to ``OpenSSL.crypto.CRL.export()``.
    Callers must now always pass an explicit ``digest``.
  - Fixed a bug with ``ASN1_TIME`` casting in ``X509.set_notBefore()``,
    ``X509.set_notAfter()``, ``Revoked.set_rev_date()``, ``Revoked.set_nextUpdate()``,
    and ``Revoked.set_lastUpdate()``. You must now pass times in the form
    ``YYYYMMDDhhmmssZ``. ``YYYYMMDDhhmmss+hhmm`` and ``YYYYMMDDhhmmss-hhmm``
    will no longer work. `#612 <https://github.com/pyca/pyopenssl/pull/612>`_
  - Deprecated the legacy "Type" aliases: ``ContextType``, ``ConnectionType``,
    ``PKeyType``, ``X509NameType``, ``X509ExtensionType``, ``X509ReqType``,
    ``X509Type``, ``X509StoreType``, ``CRLType``, ``PKCS7Type``, ``PKCS12Type``,
    ``NetscapeSPKIType``.
    The names without the "Type"-suffix should be used instead.
  - Added ``OpenSSL.crypto.X509.from_cryptography()`` and ``OpenSSL.crypto.X509.to_cryptography()``
    for converting X.509 certificate to and from pyca/cryptography objects.
  - Added ``OpenSSL.crypto.X509Req.from_cryptography()``, ``OpenSSL.crypto.X509Req.to_cryptography()``,
    ``OpenSSL.crypto.CRL.from_cryptography()``, and ``OpenSSL.crypto.CRL.to_cryptography()``
    for converting X.509 CSRs and CRLs to and from pyca/cryptography objects.
  - Added ``OpenSSL.debug`` that allows to get an overview of used library versions
    (including linked OpenSSL) and other useful runtime information using
    ``python -m OpenSSL.debug``.
  - Added a fallback path to ``Context.set_default_verify_paths()`` to accommodate
    the upcoming release of ``cryptography`` ``manylinux1`` wheels.
- Drop python-pyOpenSSL=replace-expired-cert.patch . Applied upstream.
- Drop python-pyOpenSSL-always-overflow.patch. Applied upstream.
* Thu Aug 10 2017 ro@suse.de
- add patch to always trigger overflow in the testsuite
  (gh#pyca/pyopenssl#657) b3460c6a9a45a016d1ab65c149c606fa3f07096d
  python-pyOpenSSL-always-overflow.patch
* Tue Jun 13 2017 dimstar@opensuse.org
- Add python-pyOpenSSL=replace-expired-cert.patch: the root cert
  expired, mking the test suite fail. Replace the certificate with
  a new one, valid for 20 years (gh#pyca/pyopenssl#637).
* Fri May  5 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to 17.0.0
  * Added ``OpenSSL.X509Store.set_time()`` to set a custom
    verification time when verifying certificate chains.
  * Added a collection of functions for working with OCSP stapling.
    None of these functions make it possible to validate OCSP
    assertions, only to staple them into the handshake and to
    retrieve the stapled assertion if provided.
    Users will need to write their own code to handle OCSP
    assertions.
    We specifically added: ``Context.set_ocsp_server_callback``,
    ``Context.set_ocsp_client_callback``, and
    ``Connection.request_ocsp``.
  * Changed the ``SSL`` module's memory allocation policy to
    avoid zeroing memory it allocates when unnecessary.
    This reduces CPU usage and memory allocation time by an amount
    proportional to the size of the allocation.
    For applications that process a lot of TLS data or that use
    very lage allocations this can provide considerable performance
    improvements.
  * Automatically set ``SSL_CTX_set_ecdh_auto()`` on
    ``OpenSSL.SSL.Context``.
  - Fix empty exceptions from ``OpenSSL.crypto.load_privatekey()``.
- Rebase bug-lp-1265482.diff
- Rebase rsa128-i586.patch
- Rebase skip-networked-test.patch
* Wed Nov 16 2016 dmueller@suse.com
- fix source url
* Tue Nov 15 2016 mlin@suse.com
- Change source url to pypi.io
  * version 16.2.0 source tarball failed to download from pypi.python.org
* Mon Nov 14 2016 mlin@suse.com
- Update to 16.2.0
  * Deprecations
  * * Dropped support for OpenSSL 0.9.8.
  * Changes
  * * Fix memory leak in OpenSSL.crypto.dump_privatekey() with FILETYPE_TEXT. #496
  * * Enable use of CRL (and more) in verify context. #483
  * * OpenSSL.crypto.PKey can now be constructed from cryptography objects and also
    exported as such. #439
  * * Support newer versions of cryptography which use opaque structs for OpenSSL
    1.1.0 compatibility.
  * * Fixed compatibility errors with OpenSSL 1.1.0.
  * * Fixed an issue that caused failures with subinterpreters and embedded Pythons.
    [#552]
* Mon May 16 2016 jmatejek@suse.com
- added %%check section with testsuite
- skip-networked-test.patch - mark a test as networked so that we can
  specify non-network test run
- rsa128-i586.patch - sidestep a crasher bug on 32bit platforms
  by generating reasonably-sized RSA keys instead of small 128bit ones
* Mon May  9 2016 hpj@urpla.net
- update to 16.0.0
  Backward-incompatible changes:
  * Python 3.2 support has been dropped. It never had significant real world
    usage and has been dropped by our main dependency cryptography. Affected
    users should upgrade to Python 3.3 or later.
  Deprecations:
  * The support for EGD has been removed. The only affected function
    OpenSSL.rand.egd() now uses os.urandom() to seed the internal PRNG instead.
    Please see pyca/cryptography#1636 for more background information on this
    decision. In accordance with our backward compatibility policy
    OpenSSL.rand.egd() will be removed no sooner than a year from the release of
    16.0.0.
  * Please note that you should use urandom for all your secure random number
    needs.
  * Python 2.6 support has been deprecated. Our main dependency cryptography
    deprecated 2.6 in version 0.9 (2015-05-14) with no time table for actually
    dropping it. pyOpenSSL will drop Python 2.6 support once cryptography does.
  Changes:
  * Fixed OpenSSL.SSL.Context.set_session_id, OpenSSL.SSL.Connection.renegotiate,
    OpenSSL.SSL.Connection.renegotiate_pending, and
    OpenSSL.SSL.Context.load_client_ca. They were lacking an implementation since
    0.14. #422
  * Fixed segmentation fault when using keys larger than 4096-bit to sign data.
    [#428]
  * Fixed AttributeError when OpenSSL.SSL.Connection.get_app_data() was called
    before setting any app data. #304
  * Added OpenSSL.crypto.dump_publickey() to dump OpenSSL.crypto.PKey objects
    that represent public keys, and OpenSSL.crypto.load_publickey() to load such
    objects from serialized representations. #382
  * Added OpenSSL.crypto.dump_crl() to dump a certificate revocation list out to
    a string buffer. #368
  * Added OpenSSL.SSL.Connection.get_state_string() using the OpenSSL binding
    state_string_long. #358
  * Added support for the socket.MSG_PEEK flag to OpenSSL.SSL.Connection.recv()
    and OpenSSL.SSL.Connection.recv_into(). #294
  * Added OpenSSL.SSL.Connection.get_protocol_version() and
    OpenSSL.SSL.Connection.get_protocol_version_name(). #244
  * Switched to utf8string mask by default. OpenSSL formerly defaulted to a
    T61String if there were UTF-8 characters present. This was changed to
    default to UTF8String in the config around 2005, but the actual code didn’t
    change it until late last year. This will default us to the setting that
    actually works. To revert this you can call
    OpenSSL.crypto._lib.ASN1_STRING_set_default_mask_asc(b"default"). #234
- fixed paths in bug-lp-1265482.diff
- fixed doc generation
- spec clean up
* Tue Jul 14 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Wed Apr 22 2015 mcihar@suse.cz
- Do not hardcode version in file list
* Wed Apr 22 2015 mcihar@suse.cz
- udapte to 0.15.1
  * OpenSSL/SSL.py, OpenSSL/test/test_ssl.py: Fix a regression
  present in 0.15, where when an error occurs and no errno() is set,
  a KeyError is raised.  This happens, for example, if
  Connection.shutdown() is called when the underlying transport has
  gone away.
  * OpenSSL/rand.py, OpenSSL/SSL.py: APIs which previously accepted
  filenames only as bytes now accept them as either bytes or
  unicode (and respect sys.getfilesystemencoding()).
  * OpenSSL/SSL.py: Add Cory Benfield's next-protocol-negotiation
  (NPN) bindings.
  * OpenSSL/SSL.py: Add ``Connection.recv_into``, mirroring the
  builtin ``socket.recv_into``.  Based on work from Cory Benfield.
  * OpenSSL/test/test_ssl.py: Add tests for ``recv_into``.
  * OpenSSL/crypto.py: Expose ``X509StoreContext`` for verifying certificates.
  * OpenSSL/test/test_crypto.py: Add intermediate certificates for
  * OpenSSL/SSL.py: ``Connection.shutdown`` now propagates errors from the
  underlying socket.
  * OpenSSL/SSL.py: Fixed a regression ``Context.check_privatekey``
  causing it to always succeed - even if it should fail.
  * OpenSSL/crypto.py: Fixed a regression where calling ``load_pkcs7_data``
  with ``FILETYPE_ASN1`` would fail with a ``NameError``.
  * OpenSSL/SSL.py: Fix a regression in which the first argument of
* Mon Feb 24 2014 mvyskocil@suse.com
- update to 0.14
  * Support for TLSv1.1 and TLSv1.2
  * First-class support for PyPy
  * New flags, such as MODE_RELEASE_BUFFERS and OP_NO_COMPRESSION
  * Some APIs to access to the SSL session cache
  * A variety of bug fixes for error handling cases
  * Documentation has been converted from LaTeX
    + python-pyOpenSSL-doc is now build from single spec file
  * pyOpenSSL now depends on cryptography, so it became pure-python
    module
    + changed to noarch package, add proper dependencies
  * Development moved to github
    + changed Url tag respectivelly
- refreshed bug-lp-1265482.diff
* Thu Jan  2 2014 dmueller@suse.com
-Add bug-lp-1265482.diff; fix testsuite for SLE11 (bnc#855666)
* Fri Sep 13 2013 jmatejek@suse.com
- update to 0.13.1
  * fixes NUL byte handling in subjectAltName (bnc#839107, CVE-2013-4314)
* Fri Apr  5 2013 speilicke@suse.com
- Package LICENSE
* Tue Jul 10 2012 msuman@opensuse.org
- Update to version 0.13
  * Add OPENSSL_VERSION_NUMBER, SSLeay_version and related
    constants for retrieving version information about the
    underlying OpenSSL library.
  * Support OpenSSL 1.0.0a and related changes.
  * Remove SSLv2 support if the underlying OpenSSL library does
    not provide it.
  * Add a new method to the X509 type, get_signature_algorithm.
  * Add a new method to the Connection type, get_peer_cert_chain.
  * Add the PKey.check method to verify the internal consistency
    of a PKey instance.
  * Bug fixes.
* Thu Sep  1 2011 saschpe@suse.de
- Changed license to Apache-2.0, to fix bnc#715423
* Wed Aug 31 2011 saschpe@suse.de
- Initial version, obsoletes 'python-openssl':
  * Builds properly on all SUSE version
  * Has real HTML documentation
